@@ -11,7 +11,7 @@ function(node, bins = 50)
     end <- min(c(samplesGetEnd(), modelIteration()))
     numChains <- samplesGetLastChain() - samplesGetFirstChain() + 1
     sampleSize <- sampleSize %/% numChains
-    beg <- end - (sampleSize - 1) 
+    beg <- end - (sampleSize * samplesGetThin() - 1)
     delta <- sampleSize %/% bins
     grid <- ((1 : (bins - 1)) * delta) + beg
     grid <- c(grid, end)
