@@ -11,7 +11,11 @@ function(fileName)
         stop(fileName, " is a directory, but a file is required")
     command <- paste("BugsEmbed.SetFilePath(", sQuote(fileName), 
         ");BugsEmbed.ParseGuard;BugsEmbed.Parse", sep = "")
-    .C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")
+    if (!is.R()) {
+    	command <- gsub ("\\\\", "/", command)
+    	command <- gsub ("//", "/", command)
+    }
+    .C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE = "BRugs")
     if(getOption("BRugsVerbose")) 
         buffer()
 }
