@@ -3,7 +3,7 @@ function()
 #   Enable Dynamic Compilation
 {
     command <- "BugsEmbed.CompiledGuard; BugsEmbed.EnableDynamic"
-    invisible(.C("Integer", command, nchar(command), integer(1), integer(1), PACKAGE="BRugs")[[3]])
+    invisible(.C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")[[3]])
 }
 
 "modelDisableDynamic" <-
@@ -11,5 +11,5 @@ function()
 #   Disable Dynamic Compilation
 {
     command <- "BugsEmbed.CompiledGuard; BugsEmbed.DisableDynamic"
-    invisible(.C("Integer", command, nchar(command), integer(1), integer(1), PACKAGE="BRugs")[[3]])
+    invisible(.C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")[[3]])
 }
