@@ -3,8 +3,12 @@ function(node, chain, beg = samplesGetBeg(), end = samplesGetEnd(),
 thin = samplesGetThin(), plot = TRUE, mfrow = c(3, 2), ask = NULL, ann = TRUE, ...)
 #   Plot auto correlation function
 {
-    if(is.null(ask))
+    if(is.null(ask)) {
+      if (is.R())
         ask <- !((dev.cur() > 1) && !dev.interactive())
+      else
+        ask <- !((dev.cur() > 1) && !interactive())
+    }
     oldBeg <- samplesGetBeg()
     oldEnd <- samplesGetEnd()
     oldFirstChain <- samplesGetFirstChain()
@@ -27,7 +31,10 @@ thin = samplesGetThin(), plot = TRUE, mfrow = c(3, 2), ask = NULL, ann = TRUE, .
     thin <- max(c(thin, 1))
     samplesSetThin(thin)
     mons <- samplesMonitors(node)
-    par(mfrow = mfrow, ask = ask, ann = ann)
+    if (is.R())
+      par(mfrow = mfrow, ask = ask, ann = ann)
+    else
+      par(mfrow = mfrow, ask = ask)
     result <- lapply(mons, plotAutoC, plot = plot, ...)
     names(result) <- mons
     if(plot) invisible(result)
