@@ -4,8 +4,12 @@ firstChain = samplesGetFirstChain(), lastChain = samplesGetLastChain(),
 thin = samplesGetThin(), plot = TRUE, mfrow = c(3, 1), ask = NULL, ann = TRUE, ...)
 #   Plot history                    
 {
-    if(is.null(ask))
+    if(is.null(ask)) {
+      if (is.R())
         ask <- !((dev.cur() > 1) && !dev.interactive())
+      else
+        ask <- !((dev.cur() > 1) && !interactive())
+    }
     oldBeg <- samplesGetBeg()
     oldEnd <- samplesGetEnd()
     oldFirstChain <- samplesGetFirstChain()
@@ -25,7 +29,10 @@ thin = samplesGetThin(), plot = TRUE, mfrow = c(3, 1), ask = NULL, ann = TRUE, .
     thin <- max(c(thin, 1))
     samplesSetThin(thin)
     mons <- samplesMonitors(node)
-    par(mfrow = mfrow, ask = ask, ann = ann)
+    if (is.R())
+      par(mfrow = mfrow, ask = ask, ann = ann)
+    else 
+      par(mfrow = mfrow, ask = ask)
     result <- lapply(mons, plotHistory, plot = plot, ...)
     names(result) <- mons
     if(plot) invisible(result)
