@@ -9,7 +9,7 @@ function(node)
     command <- "SamplesEmbed.SampleSize"
     sampleSize <- as.integer(.C("Integer", command, nchar(command), 
         integer(1), integer(1), PACKAGE="BRugs")[[3]])
-    command <- "SamplesEmbed.Sample"
+    command <- "SamplesEmbed.SampleValues"
     .C("RealArray", command, nchar(command), 
-        real(sampleSize), sampleSize, integer(1), PACKAGE="BRugs")[[3]]
+       double(sampleSize), sampleSize, integer(1), PACKAGE="BRugs")[[3]]
 }
